## Who is AEGIS for?

### If you are a theorist...

AEGIS can help advance theoretical work by enabling study of topics with otherwise limited tractability – e.g. complex scenarios (e.g. complex genetics, complex environment) and dynamic and transient phenomena (population dynamics, evolutionary dynamics). As a bottom-up model, AEGIS functions complementary to existing methods, and has the potential of adding new perspectives to important topics in the field of aging. These are feasibility and conditions for evolution of programmed aging, significance of intergenerational transfers on evolution of longevity and alternative ways of evolving longevity, impact of population dynamic (e.g. bottlenecks) and evolution dynamic (e.g. group selection, linkage) on evolution of aging, quantifying contributions of genetic theories of aging (mutation accumulation and antagonistic pleiotropy), including others. Furthermore, AEGIS can explore generality of existing insights by testing them under loosened assumptions (which have low tractability for classical methods). As a comparatively simpler method, AEGIS can help boost engagement with a theoretical tool by otherwise disinclined researchers; and accelerate advancement in a parallel theoretical track by providing a tool that is arguably easier to extend than classical methods. Lastly, AEGIS could provide simulated datasets used as input datasets for validation of novel computational methods.

### If you are an experimentalist...

For experimentalists, AEGIS can provide value before and after running experiments. During experimental planning, AEGIS can help formulate hypotheses (model to-be-tested) by being a cognitive aid that helps identify factors that matter. Furthermore, it can help explore their interactions as well as gauge their relative impact, it can help test plausibility of hypotheses thus prioritizing or forgoing experiments; it can help estimate relevant evolutionary time scales and effect scales important for timing and amount when designing sampling plans. For conducted and analyzed experiments, AEGIS can help test generality and broader relevance of their findings by simulating experimental scenarios with comparable, loosened or altered assumptions and comparing the outcomes with observations. Again, as a complementary method (that is comparatively cheap, fast and requires no animals) it should be considered independent corroboration of empirical findings.

### If you are an educator or an enthusiast...

For educators, AEGIS is a unique platform to teach and learn about a wide number of concepts in a way that is arguably more intuitive and less dependent on high levels of mathematical knowledge and other advanced/niche knowledge. Individual-based models are already an educational staple in the field, such as for demostrating the Lotka-Volterra predator-prey dynamics; and simulations more broadly are common (e.g. simulations of genetic drift, or epidemiological models). This is probably because they focus on modeling of relevant entities and processes, keeping technical and operational aspects secondary. Furthermore, AEGIS ensures a low barrier to entry by providing a webserver (or, alternatively, as simple installation on a personal computer) with built-in analytics and visualizations using recognizable plot types.
